@@ -1,7 +1,7 @@
 package App::IDXUtils;
 
-our $DATE = '2018-09-08'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2020-12-24'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Command-line utilities related to Indonesian Stock Exchange
@@ -18,7 +18,7 @@ App::IDXUtils - Command-line utilities related to Indonesian Stock Exchange
 
 =head1 VERSION
 
-This document describes version 0.002 of App::IDXUtils (from Perl distribution App-IDXUtils), released on 2018-09-08.
+This document describes version 0.003 of App::IDXUtils (from Perl distribution App-IDXUtils), released on 2020-12-24.
 
 =head1 SYNOPSIS
 
@@ -31,6 +31,8 @@ Exchange (IDX):
 
 =item * L<list-idx-boards>
 
+=item * L<list-idx-brokers>
+
 =item * L<list-idx-firms>
 
 =item * L<list-idx-sectors>
@@ -47,7 +49,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-IDXUtils>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-IDXUtils>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-IDXUtils/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -59,7 +61,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
